@@ -319,7 +319,7 @@ pub fn bjtc_to_duration(
 }
 
 #[cfg(test)]
-mod bjtc_test {
+mod test {
     use super::*;
     use std::thread;
 
@@ -332,7 +332,7 @@ mod bjtc_test {
         let t1 = bjtc_from_duration(&anchor, now.elapsed().as_secs_f64() * 1000.0);
         let t2 = bjtc_to_duration(&anchor, t1).unwrap();
         let diff = t2.as_secs_f64() - 0.7;
-        assert!(diff > -0.0014 && diff < 0.0014);
+        assert!(diff > -0.01 && diff < 0.01);
 
         let t1 = bjtc_from_duration(&anchor, 1000.0);
         let t3 = bjtc_to_duration(&anchor, t1 - 1000);
@@ -345,6 +345,6 @@ mod bjtc_test {
             .unwrap()
             .as_secs_f64()
             - 0.7;
-        assert!(diff > -0.0014 && diff < 0.0014);
+        assert!(diff > -0.1 && diff < 0.1);
     }
 }
